action Package
==============

:mod:`action` Package
---------------------

.. automodule:: camelot.admin.action
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`application_action` Module
--------------------------------

.. automodule:: camelot.admin.action.application_action
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`base` Module
------------------

.. automodule:: camelot.admin.action.base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`form_action` Module
-------------------------

.. automodule:: camelot.admin.action.form_action
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`list_action` Module
-------------------------

.. automodule:: camelot.admin.action.list_action
    :members:
    :undoc-members:
    :show-inheritance:

